@@ -45,4 +45,18 @@ STATE_AWAY_MODE = "awayModeEnabled"
 STATE_FAN_SLEEP_TIMER = "fanSleepTimer"
 STATE_LIGHT_SLEEP_TIMER = "lightSleepTimer"
 STATE_ADAPTIVE_LEARNING = "adaptiveLearning"
-STATE_CLIENT_ID = "clientId"
+
+
+INFO_CLIENT_ID = "clientId"
+INFO_MAC = "mac"
+INFO_LIGHT_TYPE = "lightType"
+INFO_FAN_TYPE = "fanType"
+INFO_FAN_MOTOR_TYPE = "fanMotorType"
+INFO_PRODUCTION_LOT_NUMBER = "productionLotNumber"
+INFO_PRODUCT_SKU = "productSku"
+INFO_OWNER = "owner"
+INFO_FEDERATED_IDENTITY = "federatedIdentity"
+INFO_DEVICE_NAME = "deviceName"
+INFO_FIRMWARE_VERSION = "firmwareVersion"
+INFO_MAIN_MCU_FIRMWARE_VERSION = "mainMcuFirmwareVersion"
+INFO_FIRMWARE_URL = "firmwareUrl"
